pub struct CreatepsbtParams {
pub inputs: Vec<Value>,
pub outputs: Vec<Value>,
pub locktime: u32,
pub replaceable: bool,
pub version: u32,
}Expand description
Creates a transaction in the Partially Signed Transaction format. Implements the Creator role. Note that the transaction“s inputs are not signed, and it is not stored in the wallet or transmitted to the network.
Fields
inputs: Vec<Value>outputs: Vec<Value>locktime: u32replaceable: boolversion: u32Trait Implementations
Sourceimpl Debug for CreatepsbtParams
impl Debug for CreatepsbtParams