pub struct CreatewalletdescriptorParams {
pub _type: String,
pub options: Value,
}Expand description
Creates the wallet“s descriptor for the given address type. The address type must be one that the wallet does not already have a descriptor for. Requires wallet passphrase to be set with walletpassphrase call if wallet is encrypted.
Fields
_type: Stringoptions: ValueTrait Implementations
Sourceimpl Debug for CreatewalletdescriptorParams
impl Debug for CreatewalletdescriptorParams