pub struct GenerateblockParams {
pub output: String,
pub transactions: Vec<Value>,
pub submit: bool,
}Expand description
Mine a set of ordered transactions to a specified address or descriptor and return the block hash.
Fields
output: Stringtransactions: Vec<Value>submit: boolTrait Implementations
Sourceimpl Debug for GenerateblockParams
impl Debug for GenerateblockParams