GetblockParams

Struct GetblockParams 

pub struct GetblockParams {
    pub blockhash: BlockHash,
    pub verbosity: u32,
}
If verbosity is 0, returns a string that is serialized, hex-encoded data for block “hash”. If verbosity is 1, returns an Object with information about block . If verbosity is 2, returns an Object with information about block and information about each transaction. If verbosity is 3, returns an Object with information about block and information about each transaction, including prevout information for inputs (only for unpruned blocks in the current best chain).

Fields

blockhash: BlockHashverbosity: u32