pub struct GetblockheaderParams {
pub blockhash: BlockHash,
pub verbose: bool,
}Expand description
If verbose is false, returns a string that is serialized, hex-encoded data for blockheader “hash”.
If verbose is true, returns an Object with information about blockheader
Fields
blockhash: BlockHashverbose: boolTrait Implementations
Sourceimpl Debug for GetblockheaderParams
impl Debug for GetblockheaderParams