pub struct GetnetworkhashpsParams {
pub nblocks: u64,
pub height: u64,
}Expand description
Returns the estimated network hashes per second based on the last n blocks. Pass in [blocks] to override # of blocks, -1 specifies since last difficulty change. Pass in [height] to estimate the network speed at the time when a certain block was found.
Fields
nblocks: u64height: u64Trait Implementations
Sourceimpl Debug for GetnetworkhashpsParams
impl Debug for GetnetworkhashpsParams