pub struct SubmitheaderParams {
pub hexdata: String,
}Expand description
Decode the given hexdata as a header and submit it as a candidate chain tip if valid. Throws when the header is invalid.
Fields
hexdata: StringTrait Implementations
Sourceimpl Debug for SubmitheaderParams
impl Debug for SubmitheaderParams