SubmitpackageParams

Struct SubmitpackageParams 

pub struct SubmitpackageParams {
    pub package: Vec<Value>,
    pub maxfeerate: f64,
    pub maxburnamount: f64,
}
Submit a package of raw transactions (serialized, hex-encoded) to local node. The package will be validated according to consensus and mempool policy rules. If any transaction passes, it will be accepted to mempool. This RPC is experimental and the interface may be unstable. Refer to doc/policy/packages.md for documentation on package policies. Warning: successful submission does not mean the transactions will propagate throughout the network.

Fields

package: Vec<Value>maxfeerate: f64maxburnamount: f64