pub struct TestmempoolacceptParams {
pub rawtxs: Vec<Value>,
pub maxfeerate: f64,
}Expand description
Returns result of mempool acceptance tests indicating if raw transaction(s) (serialized, hex-encoded) would be accepted by mempool.
If multiple transactions are passed in, parents must come before children and package policies apply: the transactions cannot conflict with any mempool transactions or each other.
If one transaction fails, other transactions may not be fully validated (the “allowed” key will be blank).
The maximum number of transactions allowed is 25.
This checks if transactions violate the consensus or policy rules.
See sendrawtransaction call.
Fields
rawtxs: Vec<Value>maxfeerate: f64Trait Implementations
Sourceimpl Debug for TestmempoolacceptParams
impl Debug for TestmempoolacceptParams