pub struct WalletprocesspsbtParams {
pub psbt: String,
pub sign: bool,
pub sighashtype: String,
pub bip32derivs: bool,
pub finalize: bool,
}Expand description
Update a PSBT with input information from our wallet and then sign inputs that we can sign for. Requires wallet passphrase to be set with walletpassphrase call if wallet is encrypted.
Fields
psbt: Stringsign: boolsighashtype: Stringbip32derivs: boolfinalize: boolTrait Implementations
Sourceimpl Debug for WalletprocesspsbtParams
impl Debug for WalletprocesspsbtParams