pub struct SendallParams {
pub recipients: Vec<Value>,
pub conf_target: u64,
pub estimate_mode: String,
pub fee_rate: f64,
pub options: Value,
}Expand description
EXPERIMENTAL warning: this call may be changed in future releases.
Spend the value of all (or specific) confirmed UTXOs and unconfirmed change in the wallet to one or more recipients.
Unconfirmed inbound UTXOs and locked UTXOs will not be spent. Sendall will respect the avoid_reuse wallet flag.
If your wallet contains many small inputs, either because it received tiny payments or as a result of accumulating change, consider using send_max to exclude inputs that are worth less than the fees needed to spend them.
Fields
recipients: Vec<Value>conf_target: u64estimate_mode: Stringfee_rate: f64options: ValueTrait Implementations
Sourceimpl Debug for SendallParams
impl Debug for SendallParams